@@ -15,10 +15,14 @@
 from .storagesystem import StorageSystem
 from .filestorage import FileStorage
 from .s3storage import S3Storage
+from .googlecloudstorage import GoogleCloudStorage
+from .azureblobstorage import AzureBlobStorage
 from .dynamodbstorage import DynamoDBStorage
-from .surveyctoexportstorage import SurveyCTOExportStorage
 from .surveyplatform import SurveyPlatform
 from .surveyctoplatform import SurveyCTOPlatform
+from .surveyctoexportstorage import SurveyCTOExportStorage
+from .odkexportstorage import ODKExportStorage
+from .odkplatform import ODKPlatform
 
 # report our current version, as installed
 from importlib_metadata import version
