@@ -18,8 +18,7 @@ from surveydata import StorageSystem
 import boto3
 from boto3.dynamodb import conditions
 from typing import BinaryIO
-import datetime
-import pickle
+from decimal import Decimal
 
 
 class DynamoDBStorage(StorageSystem):
@@ -247,8 +246,39 @@ class DynamoDBStorage(StorageSystem):
         if self.partition_key_name:
             submission_data[self.partition_key_name] = self.partition_key_value
 
-        # store submission data directly in table
-        self.table.put_item(Item=submission_data)
+        # because of a ridiculous boto3 restriction, convert all floats to Decimals
+        item = DynamoDBStorage._replace_floats(submission_data)
+
+        # store submission data directly in table, replacing all floats with Decimal for ridiculous boto3 limitation
+        self.table.put_item(Item=item)
+
+    @staticmethod
+    def _replace_floats(obj):
+        """
+        Replace all floats within object with Decimals, with NaN and Infinity as "".
+
+        :param obj: Object within which to replace floats
+        :type obj: Any
+        :return: Passed object with float objects converted to Decimal
+        :rtype: Any
+        """
+        if isinstance(obj, list):
+            for i in range(len(obj)):
+                obj[i] = DynamoDBStorage._replace_floats(obj[i])
+            return obj
+        elif isinstance(obj, dict):
+            for k in obj:
+                obj[k] = DynamoDBStorage._replace_floats(obj[k])
+            return obj
+        elif isinstance(obj, float):
+            # convert via str() to avoid precision errors
+            decimal_val = Decimal(str(obj))
+            if str(decimal_val) in ['Infinity', 'NaN']:
+                return ""
+            else:
+                return decimal_val
+        else:
+            return obj
 
     def get_submission(self, submission_id: str) -> dict:
         """
@@ -352,27 +382,3 @@ class DynamoDBStorage(StorageSystem):
             return {self.partition_key_name: self.partition_key_value, self.id_field_name: submission_id}
         else:
             return {self.id_field_name: submission_id}
-
-    def set_data_timezone(self, tz: datetime.timezone):
-        """
-        Set the timezone for timestamps in the data.
-
-        :param tz: Timezone for timestamps in the data
-        :type tz: datetime.timezone
-        """
-
-        self.store_metadata_binary(self.DATA_TZ_METADATA_ID, pickle.dumps(tz))
-
-    def get_data_timezone(self) -> datetime.timezone:
-        """
-        Get the timezone for timestamps in the data.
-
-        :return: Timezone for timestamps in the data (defaults to datetime.timezone.utc if unknown)
-        :rtype: datetime.timezone
-        """
-
-        # fetch metadata if possible
-        tz_metadata = self.get_metadata_binary(self.DATA_TZ_METADATA_ID)
-
-        # return stored timezone or UTC if unknown
-        return pickle.loads(tz_metadata) if len(tz_metadata) > 0 else datetime.timezone.utc
